@@ -11,15 +11,7 @@
 #' @importFrom methods hasArg
 #' @export
 #' @examples
-#' # One binary variable
-#'   mtcars %>%
-#'     dplyr::mutate(am = factor(am)) %>%
-#'     specify(response = am, success = "1") %>%
-#'     hypothesize(null = "point", p = 0.75) %>%
-#'     generate(reps = 100, type = "simulate") %>%
-#'     calculate(stat = "prop")
-#'
-#' # Permutation test
+#' # Permutation test similar to ANOVA
 #'   mtcars %>%
 #'     dplyr::mutate(cyl = factor(cyl)) %>%
 #'     specify(mpg ~ cyl) %>%
@@ -27,11 +19,14 @@
 #'     generate(reps = 100, type = "permute") %>%
 #'     calculate(stat = "F")
 
-specify <- function(x, formula, response = NULL, explanatory = NULL, success = NULL) {
+specify <- function(x, formula, response = NULL,
+                    explanatory = NULL, success = NULL) {
   assertive::assert_is_data.frame(x)
 
-  # Convert all character variables to be factor variables
-  x <- dplyr::as_tibble(x) %>% mutate_if(is.character, as.factor)
+  # Convert all character and logical variables to be factor variables
+  x <- dplyr::as_tibble(x) %>%
+    mutate_if(is.character, as.factor) %>%
+    mutate_if(is.logical, as.factor)
 
   if (!methods::hasArg(formula) && !methods::hasArg(response)) {
     stop("Please specify the response variable.")
@@ -52,21 +47,25 @@ specify <- function(x, formula, response = NULL, explanatory = NULL, success = N
   response_col <- rlang::eval_tidy(attr(x, "response"), x)
 
   if (!as.character(attr(x, "response")) %in% names(x)) {
-    stop(paste0("The response variable `", attr(x, "response"), "` cannot be found in this dataframe."))
+    stop(paste0("The response variable `", attr(x, "response"),
+                "` cannot be found in this dataframe."))
   }
 
   # if there's an explanatory var
 
   if (!(is.null(attr(x, "explanatory")))) {
     if (!as.character(attr(x, "explanatory")) %in% names(x)) {
-      stop(paste0("The explanatory variable `", attr(x, "explanatory"), "` cannot be found in this dataframe."))
+      stop(paste0("The explanatory variable `", attr(x, "explanatory"),
+                  "` cannot be found in this dataframe."))
     }
-    if (identical(as.character(attr(x, "response")), as.character(attr(x, "explanatory")))) {
-      stop("The response and explanatory variables must be different from one another.")
+    if (identical(as.character(attr(x, "response")),
+                  as.character(attr(x, "explanatory")))) {
+      stop(paste("The response and explanatory variables must be different",
+"from one another."))
     }
     explanatory_col <- rlang::eval_tidy(attr(x, "explanatory"), x)
     if (is.character(explanatory_col)) {
-      rlang::eval_tidy(attr(x, "explanatory"), x) <- as.factor(explanatory_col)
+      explanatory_col <- as.factor(explanatory_col)
     }
   }
 
@@ -77,13 +76,16 @@ specify <- function(x, formula, response = NULL, explanatory = NULL, success = N
       stop("`success` must be a string.")
     }
     if (!is.factor(response_col)) {
-      stop("`success` should only be specified if the response is a categorical variable.")
+      stop(paste("`success` should only be specified if the response is",
+"a categorical variable."))
     }
     if (!(success %in% levels(response_col))) {
-      stop(paste0(success, " is not a valid level of ", attr(x, "response"), "."))
+      stop(paste0(success, " is not a valid level of ",
+                  attr(x, "response"), "."))
     }
     if (sum(table(response_col) > 0) > 2) {
-      stop("`success` can only be used if the response has two levels. `filter()` can reduce a variable to two levels.")
+      stop(paste("`success` can only be used if the response has two levels.",
+           "`filter()` can reduce a variable to two levels."))
     }
   }
 
